HotCandy = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0", "CandyBar-2.0")

local BS = AceLibrary("Babble-Spell-2.2")

HotCandy.revision = tonumber(string.sub("$Revision: 28099 $", 12, -3))
HotCandy.date = string.sub("$Date: 2007-02-15 08:50:46 -0500 (Thu, 15 Feb 2007) $", 8, 17)

function HotCandy:OnInitialize()
	if not self.version then self.version = GetAddOnMetadata("HotCandy", "Version") end
	self.version = (self.version or "1.0") .. " |cffff8888r" .. self.revision .. "|r"
	
	self:RegisterDB("HotCandyDB")
	self:RegisterDefaults("profile", {
		growup = false,
		bonus = {druidt2 = false, priestt2 = false, druidt5 = false},
	})
	
	self.options = {
		type = "group",
		args = {
			anchor = {
				name = "Show Anchor",
				desc = "Show the Anchor for moving the Bars",
				type = "execute",
				func = "ShowAnchors",
			},
			growup = {
				name = "Grow Up",
				desc = "Toggle Grow Up of the Bars",
				type = "toggle",
				get = function()
					return self.db.profile.growup
				end,
				set = function(v)
					self.db.profile.growup = v
				end,
			},
			bonus = {
				type = "group",
				name = "Bonus",
				desc = "Configure Set Bonus attributes",
				args = {
					druid = {
						type = "group",
						name = "Druid",
						desc = "Druid Set Bonuses",
						args = {
							t2 = {
								name = "Druid T2 Rejuvenation Bonus",
								desc = "Toggle the Druid T2 Bonus on/off",
								type = "toggle",
								get = function()
									return self.db.profile.bonus.druidt2
								end,
								set = function(v)
									self.db.profile.bonus.druidt2 = v
									if self.db.profile.bonus.druidt2 then
										self.track[BS['Rejuvenation']] = 15
									else
										self.track[BS['Rejuvenation']] = 12
									end
								end,
							},
							t5 = {
								name = "Druid T5 Regrowth Bonus",
								desc = "Toggle the Druid T5 Bonus on/off",
								type = "toggle",
								get = function()
									return self.db.profile.bonus.druidt5
								end,
								set = function(v)
									self.db.profile.bonus.druidt5 = v
									if self.db.profile.bonus.druidt5 then
										self.track[BS['Regrowth']] = 27
									else
										self.track[BS['Regrowth']] = 21
									end
								end,
							},
						},
					},
					priest = {
						name = "Priest T2 Greater Heal Bonus",
						desc = "Toggle the Priest T2 Bonus on/off",
						type = "toggle",
						get = function()
							return self.db.profile.bonus.priestt2
						end,
						set = function(v)
							self.db.profile.bonus.priestt2 = v
							if self.db.profile.bonus.priestt2 then
								self.track[BS['Greater Heal']] = 15
							else
								self.track[BS['Greater Heal']] = nil
							end
						end,
					},
				}
			},
		}
	}
	
	self:RegisterChatCommand({ "/hot", "/hotcandy" }, self.options )
	
	self.spell = {}
	
	-- spell = duration
	self.track = {
		[BS['Rejuvenation']] = self.db.profile.bonus.druidt2 and 15 or 12,
		[BS['Regrowth']] = self.db.profile.bonus.druidt5 and 27 or 21,
		[BS['Renew']] = 15,
		[BS['Greater Heal']] = self.db.profile.bonus.priestt2 and 15 or nil,
		[BS['Lifebloom']] = 7,
		[BS['Gift of the Naaru']] = 15,
	}
end

function HotCandy:OnEnable()
	self:SetupFrames()
	self:RegisterEvent("UNIT_SPELLCAST_SENT", "SpellCastEvent")
	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED", "SpellCastEvent")
end

function HotCandy:SpellCastEvent(unit, spell, rank, target)
	if ( event == "UNIT_SPELLCAST_SENT" ) then
		self.spell['spell'] = spell
		self.spell['target'] = target
	elseif ( event == "UNIT_SPELLCAST_SUCCEEDED" ) then
		if self.spell['spell'] == spell then
			self:FireSpell(spell, self.spell['target'])
		end
		self.spell['spell'] = nil
	end
end

function HotCandy:FireSpell(spellName, spellTarget)
	if self.track[spellName] then
		self:ShowCandyBar(spellName.." - "..(spellTarget or ""), self.track[spellName], BS:GetSpellIcon(spellName), "green", "yellow", "orange", "red")
	end
end

function HotCandy:ShowCandyBar(text, time, icon, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10)
	local id = "HotCandy"..text
	local u = self.db.profile.growup
	self:RegisterCandyBarGroup("HotCandyGroup")
	self:SetCandyBarGroupPoint("HotCandyGroup", u and "BOTTOM" or "TOP", self.frames.anchor, u and "TOP" or "BOTTOM", 0, 0)
	self:SetCandyBarGroupGrowth("HotCandyGroup", u)
	
	self:RegisterCandyBar(id, time, text, icon, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10)
	self:RegisterCandyBarWithGroup(id, "HotCandyGroup")
	self:SetCandyBarTexture(id, "Interface\\Addons\\HotCandy\\textures\\default")
	self:SetCandyBarFade(id, 5)
	self:StartCandyBar(id, true)
end
